@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -310,14 +310,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "Falkland uharteetako ordua",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Bhutango ordua",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apiako ordu estandarra",
                "",
@@ -326,6 +318,14 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "Apiako ordua",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Bhutango ordua",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Nauruko ordua",
                "",
@@ -566,12 +566,12 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolonbiako ordu estandarra",
+        final String[] Australia_Eastern = new String[] {
+               "Australiako ekialdeko ordu estandarra",
                "",
-               "Kolonbiako udako ordua",
+               "Australiako ekialdeko udako ordua",
                "",
-               "Kolonbiako ordua",
+               "Australiako ekialdeko ordua",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -582,12 +582,12 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Australiako ekialdeko ordu estandarra",
+        final String[] Colombia = new String[] {
+               "Kolonbiako ordu estandarra",
                "",
-               "Australiako ekialdeko udako ordua",
+               "Kolonbiako udako ordua",
                "",
-               "Australiako ekialdeko ordua",
+               "Kolonbiako ordua",
                "",
             };
         final String[] Chile = new String[] {
@@ -1046,14 +1046,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Mexikoko ipar-ekialdeko ordu estandarra",
-               "",
-               "Mexikoko ipar-ekialdeko udako ordua",
-               "",
-               "Mexikoko ipar-ekialdeko ordua",
-               "",
-            };
         final String[] Easter = new String[] {
                "Pazko uharteko ordu estandarra",
                "",
@@ -1062,6 +1054,14 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
                "Pazko uharteko ordua",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Mexikoko ipar-ekialdeko ordu estandarra",
+               "",
+               "Mexikoko ipar-ekialdeko udako ordua",
+               "",
+               "Mexikoko ipar-ekialdeko ordua",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "Dumont-d\u2019Urvilleko ordua",
                "",
@@ -1335,7 +1335,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1669,7 +1668,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1902,7 +1900,6 @@ public class TimeZoneNames_eu extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Atenas" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
